@@ -12,6 +12,14 @@
 #define kGConfFrameLimit kGConfPath "/" "frame-limit"
 #define kGConfInterlace kGConfPath "/" "interlace"
 #define kGConfFrameSkip kGConfPath "/" "frameskip"
+#define kGConfFrameSkipLine kGConfPath "/" "frameskipline"
+#define kGConfFrameSkipPoly kGConfPath "/" "frameskippoly"
+#define kGConfFrameSkipSprite kGConfPath "/" "frameskipsprite"
+#define kGConfFrameSkipImage kGConfPath "/" "frameskipimage"
+#define kGConfFrameSkipBlit kGConfPath "/" "frameskipblit"
+#define kGConfWallClock kGConfPath "/" "wallclock-timing"
+#define kGConfAbbeyFix kGConfPath "/" "fix-abbey"
+#define kGConfCycleMultiplier kGConfPath "/" "cycle-multiplier"
 
 #define kGConfPlayerPathBufferLen 128
 #define kGConfPlayerPath kGConfPath "/player%d"
