@@ -18,12 +18,12 @@
 
 #include "gui.h"
 
-typedef struct gp2x_font        { int x,y,w,wmask,h,fg,bg,solid; unsigned char *data; } gp2x_font;
+enum  { MAEMOKEY_UP=(1<<4),     MAEMOKEY_LEFT=(1<<7),    MAEMOKEY_DOWN=(1<<6), MAEMOKEY_RIGHT=(1<<5),
+        MAEMOKEY_L1=(1<<10),    MAEMOKEY_R1=(1<<11),     MAEMOKEY_L2=(1<<8),   MAEMOKEY_R2=(1<<9),
+        MAEMOKEY_X =(1<<15),    MAEMOKEY_O =(1<<13),     MAEMOKEY_T =(1<<12),  MAEMOKEY_S =(1<<15),
+        MAEMOKEY_START=(1<<18), MAEMOKEY_SELECT=(1<<19), MAEMOKEY_QUIT=(1<<27) };
 
-enum  { GP2X_UP=0x1,       GP2X_LEFT=0x4,       GP2X_DOWN=0x10,  GP2X_RIGHT=0x40,
-        GP2X_START=1<<8,   GP2X_SELECT=1<<9,    GP2X_L=1<<10,    GP2X_R=1<<11,
-        GP2X_A=1<<12,      GP2X_B=1<<13,        GP2X_X=1<<14,    GP2X_Y=1<<15,
-        GP2X_VOL_UP=1<<23, GP2X_VOL_DOWN=1<<22, GP2X_PUSH=1<<27 };
+typedef struct gp2x_font        { int x,y,w,wmask,h,fg,bg,solid; unsigned char *data; } gp2x_font;
 
 #define gp2x_video_RGB_color16(R,G,B) ((unsigned short)(((((R)&0xF8)<<8)|(((G)&0xFC)<<3)|(((B)&0xF8)>>3))))
 
@@ -33,6 +33,8 @@ extern void		*gp2x_sdlwrapper_screen_pixels;
 void gp2x_video_flip();
 #define gp2x_video_flip_single() gp2x_video_flip(); //SDL_Flip(sdlscreen);
 
+void gp2x_printf(gp2x_font *f, int x, int y, const char *format, ...);
+
 extern void gp2x_change_res(int w, int h);
 extern void gp2x_video_RGB_clearscreen16(void);
 
